You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jdo-commits@db.apache.org by cl...@apache.org on 2005/07/07 00:56:58 UTC

svn commit: r209536 - /incubator/jdo/trunk/api20/src/java/javax/jdo/spi/JDOImplHelper.java

Author: clr
Date: Wed Jul  6 15:56:55 2005
New Revision: 209536

URL: http://svn.apache.org/viewcvs?rev=209536&view=rev
Log:
JDO-80 change method newObjectIdInstance(Class, String) to newObjectIdInstance(Class, Object)

Modified:
    incubator/jdo/trunk/api20/src/java/javax/jdo/spi/JDOImplHelper.java

Modified: incubator/jdo/trunk/api20/src/java/javax/jdo/spi/JDOImplHelper.java
URL: http://svn.apache.org/viewcvs/incubator/jdo/trunk/api20/src/java/javax/jdo/spi/JDOImplHelper.java?rev=209536&r1=209535&r2=209536&view=diff
==============================================================================
--- incubator/jdo/trunk/api20/src/java/javax/jdo/spi/JDOImplHelper.java (original)
+++ incubator/jdo/trunk/api20/src/java/javax/jdo/spi/JDOImplHelper.java Wed Jul  6 15:56:55 2005
@@ -182,15 +182,15 @@
     }
     
     /** Create a new instance of the ObjectId class of this <code>PersistenceCapable</code>
-     * class, using the <code>String</code> form of the constructor.
+     * class, using the <code>Object</code> form of the constructor.
      * @return the new ObjectId instance, or <code>null</code> if the class is not registered.
      * @param str the <code>String</code> form of the object id
      * @param pcClass the <code>PersistenceCapable</code> class.
      */    
-    public Object newObjectIdInstance (Class pcClass, String str) {
+    public Object newObjectIdInstance (Class pcClass, Object obj) {
         Meta meta = getMeta (pcClass);
         PersistenceCapable pcInstance = meta.getPC();
-        return pcInstance == null?null:pcInstance.jdoNewObjectIdInstance(str);
+        return (pcInstance == null)?null:pcInstance.jdoNewObjectIdInstance(obj);
     }
     
     /** Copy fields from an outside source to the key fields in the ObjectId.
@@ -182,15 +182,15 @@
      * @return the new ObjectId instance, or <code>null</code> if the class is not registered.
-     * @param str the <code>String</code> form of the object id
+     * @param obj the <code>Object</code> form of the object id
      * @param pcClass the <code>PersistenceCapable</code> class.
      */    